@@ -10,7 +10,7 @@ from decimal import Decimal
 
 import proteus.config
 
-__version__ = "6.0.3"
+__version__ = "6.0.6"
 __all__ = ['Model', 'Wizard', 'Report']
 
 _MODELS = threading.local()
@@ -1274,10 +1274,15 @@ class Report(object):
         self._proxy = self._config.get_proxy(name, type='report')
 
     def execute(self, models=None, data=None):
-        ids = [m.id for m in models] if models else data.get('ids', [])
+        if models:
+            ids = [m.id for m in models]
+        elif data:
+            ids = data.get('ids', [])
+        else:
+            ids = []
         if data is None:
             data = {
-                'id': ids[0],
+                'id': ids[0] if ids else None,
                 'ids': ids,
                 }
             if models:
